# telepotpro
An improved version of telepot by nickoala, with support for newer features and some bugfixes.


## Fixes and mods added to telepot
Consult this for a list of things added to telepot and to see what I am currently planning on doing.

- [x] Fixed requests crashing with urllib3 >= 1.24.2
- [x] Added "deleted" text format option in HTML and MD
- [x] Fixed bot crashing when receiving a poll
- [x] Fully implemented polls (incoming)
- [x] Added support for dice messages
- [x] Fix urllib connections pooling
- [x] Fix requests to telegram servers timeout


## Original links & description
telepot - Python framework for Telegram Bot API

- [Original Repo »](https://github.com/nickoala/telepot)
- [Introduction »](http://telepot.readthedocs.io/en/latest/)
- [Reference »](http://telepot.readthedocs.io/en/latest/reference.html)
- [Examples »](https://github.com/nickoala/telepot/tree/master/examples)
- [Changelog »](https://github.com/nickoala/telepot/blob/master/CHANGELOG.md)
